Documentation
¶
Index ¶
- Constants
- type App
- type AppInfo
- type Option
- func Context(ctx context.Context) Option
- func Endpoint(endpoints ...*url.URL) Option
- func ID(id string) Option
- func Metadata(metadata map[string]string) Option
- func Name(name string) Option
- func Server(srv ...transport.Server) Option
- func Signal(sigs ...os.Signal) Option
- func StopTimeout(t time.Duration) Option
- func Version(version string) Option
Constants ¶
const Release = "v1.0.0"
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type App ¶
type App struct {
// contains filtered or unexported fields
}
type AppInfo ¶
type AppInfo interface {
ID() string
Name() string
Version() string
Metadata() map[string]string
Endpoint() []string
}
AppInfo is application context value.
Directories
¶
| Path | Synopsis |
|---|---|
|
auth
|
|
|
examples
|
|
|
httpclient
command
|
|
|
third_party
|
|
|
forked/go-workgroup
Package workgroup provides synchronization for groups of related goroutines.
|
Package workgroup provides synchronization for groups of related goroutines. |
Click to show internal directories.
Click to hide internal directories.