Documentation
¶
Index ¶
- Constants
- func FromECDSA(priv *ecdsa.PrivateKey) []byte
- func FromECDSAPub(pub *ecdsa.PublicKey) []byte
- func GenerateKey() (*ecdsa.PrivateKey, error)
- func HexToECDSA(hexkey string) (*ecdsa.PrivateKey, error)
- func Keccak256(data ...[]byte) []byte
- func S256() elliptic.Curve
- func ToECDSA(b []byte) (*ecdsa.PrivateKey, error)
- type Address
- type KeccakState
Constants ¶
const AddressLength = 20
Variables ¶
This section is empty.
Functions ¶
func FromECDSA ¶
func FromECDSA(priv *ecdsa.PrivateKey) []byte
func FromECDSAPub ¶
func GenerateKey ¶
func GenerateKey() (*ecdsa.PrivateKey, error)
func HexToECDSA ¶
func HexToECDSA(hexkey string) (*ecdsa.PrivateKey, error)
Types ¶
type KeccakState ¶
KeccakState wraps sha3.state. In addition to the usual hash methods, it also supports Read to get a variable amount of data from the hash state. Read is faster than Sum because it doesn't copy the internal state, but also modifies the internal state.
Click to show internal directories.
Click to hide internal directories.